@@ -5,8 +5,8 @@
 # 
 # Needs more errorchecking.
 
-
-make HTMLFMT=chm html CSSFILE=/fpc/fpc/utils/fpdoc/fpdoc.css FPDOC=fpdoc
+export FPCSRCDIR=/fpc/fpc
+make HTMLFMT=chm html CSSFILE=$FPCSRCDIR/utils/fpdoc/fpdoc.css FPDOC=fpdoc FPCSRCDIR=$FPCSRCDIR |tee buildlog.txt
 
 fpc relinkdocs.pp
 fpc compilelatexchm.pp
@@ -37,4 +37,4 @@ cp ref-old/*.css ref
 ./compilelatexchm ref "Reference Guide"  ref/ref.kwd
 ./compilelatexchm fpdoc "FPDoc documentation"
  
-./gentoc . .
\ No newline at end of file
+./gentoc . .
